/*
 */
package de.unikassel.ir.vsr.test;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashSet;
import java.util.Set;

import de.unikassel.ir.vsr.HTMLDocStOp;
import de.unikassel.ir.vsr.HTMLDocument;

import junit.framework.TestCase;

/**
 * TestCase für das {@link HTMLDocument}. Prüft anhand einer vorgegebenen URL,
 * ob die Terme richtig extrahiert werden und die ALT-, TITLE-Texte (usw.) auch
 * berücksichtigt werden.
 * 
 * @author chs
 * @version 1 (bkr)
 */
public class HTMLDocumentTest extends TestCase {
	private HTMLDocument _doc;

	public void setUp() {
		try {

			URL url = new URL(
					"http://www.kde.cs.uni-kassel.de/lehre/ws2007-08/IR/uebungen/parseTest.html");
			_doc = new HTMLDocument(url);
			_doc.read(url.openStream());
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	/*
	 * Überprüft die Anzahl einzelner Terme. 
	 */

	public void testTerms() {
		String[] words = {"simpson", "itchi", "scratchi", "imag", "titl", "show", "mous"};
		
		int[] freqs = { 2, 8, 8, 1, 1, 8, 1};
	
		for (int i = 0; i < words.length; i++) {
			assertEquals(freqs[i], _doc.getTermCount(words[i]));
		}
	}
	/*
	 * Prüft die Anzahl aller Terme (des gesamten Dokumentes), nicht nur die unterschiedlichen
	 * Terme. Dafür muss size() in DocumentImpl richtig implementiert werden.
	 */
	
	public void testSize() {
		int nTerms = 89;
	   
		assertEquals(nTerms, _doc.size());
	}

	/*
	 * prüft ob Links extrahiert wurden
	 */
	public void testLinks() throws MalformedURLException {
		Set<URL> expected = new HashSet<URL>();
		expected.add(new URL("http://en.wikipedia.org/wiki/Itchy_&_Scratchy"));

		assertEquals(expected, _doc.extractLinks());
	}
	
}
